Files
Angular-Cn/packages
Pawel Kozlowski fcdd06896e perf(ivy): avoid megamorphic reads during property binding (#32574)
While determining a property name to bind to we were checking a mapping object
resulting in the megamorphic read. Replacing such read with a series of if checks
speeds up rproprty update benchmark ~30% (~1400ms down to ~1000ms).

PR Close #32574
2019-09-12 06:30:08 -04:00
..
2019-01-11 11:15:59 -08:00

Angular

The sources for this package are in the main Angular repo. Please file issues and pull requests against that repo.

License: MIT